import { Subject } from 'rxjs';
import { TabExpViewBase } from '@/studio-core';
import HRArchivesService from '@/service/hrarchives/hrarchives-service';
import HRArchivesAuthService from '@/authservice/hrarchives/hrarchives-auth-service';
import TabExpViewEngine from '@engine/view/tab-exp-view-engine';
import HRArchivesUIService from '@/uiservice/hrarchives/hrarchives-ui-service';

/**
 * 档案视图基类
 *
 * @export
 * @class HRArchivesV_006Base
 * @extends {TabExpViewBase}
 */
export class HRArchivesV_006Base extends TabExpViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_006Base
     */
    protected appDeName: string = 'hrarchives';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_006Base
     */
    protected appDeKey: string = 'hrarchivesid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HRArchivesV_006Base
     */
    protected appDeMajor: string = 'hrarchivesname';

    /**
     * 实体服务对象
     *
     * @type {HRArchivesService}
     * @memberof HRArchivesV_006Base
     */
    protected appEntityService: HRArchivesService = new HRArchivesService;

    /**
     * 实体权限服务对象
     *
     * @type HRArchivesUIService
     * @memberof HRArchivesV_006Base
     */
    public appUIService: HRArchivesUIService = new HRArchivesUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HRArchivesV_006Base
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HRArchivesV_006Base
     */
    protected model: any = {
        srfCaption: 'entities.hrarchives.views.v_006.caption',
        srfTitle: 'entities.hrarchives.views.v_006.title',
        srfSubTitle: 'entities.hrarchives.views.v_006.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HRArchivesV_006Base
     */
    protected containerModel: any = {
        view_tabexppanel: { name: 'tabexppanel', type: 'TABEXPPANEL' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'c16477290fe18f68c65916e3cbee4a65';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HRArchivesV_006Base
     */
    public engine: TabExpViewEngine = new TabExpViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HRArchivesV_006Base
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            keyPSDEField: 'hrarchives',
            majorPSDEField: 'hrarchivesname',
            isLoadDefault: true,
        });
    }


}