import { Subject } from 'rxjs';
import { PickupViewBase } from '@/studio-core';
import HREmployeeService from '@/service/hremployee/hremployee-service';
import HREmployeeAuthService from '@/authservice/hremployee/hremployee-auth-service';
import PickupViewEngine from '@engine/view/pickup-view-engine';
import HREmployeeUIService from '@/uiservice/hremployee/hremployee-ui-service';

/**
 * 员工数据选择视图视图基类
 *
 * @export
 * @class HREmployeePickupViewBase
 * @extends {PickupViewBase}
 */
export class HREmployeePickupViewBase extends PickupViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof HREmployeePickupViewBase
     */
    protected appDeName: string = 'hremployee';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof HREmployeePickupViewBase
     */
    protected appDeKey: string = 'employeeid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof HREmployeePickupViewBase
     */
    protected appDeMajor: string = 'employeename';

    /**
     * 实体服务对象
     *
     * @type {HREmployeeService}
     * @memberof HREmployeePickupViewBase
     */
    protected appEntityService: HREmployeeService = new HREmployeeService;

    /**
     * 实体权限服务对象
     *
     * @type HREmployeeUIService
     * @memberof HREmployeePickupViewBase
     */
    public appUIService: HREmployeeUIService = new HREmployeeUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof HREmployeePickupViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof HREmployeePickupViewBase
     */
    protected model: any = {
        srfCaption: 'entities.hremployee.views.pickupview.caption',
        srfTitle: 'entities.hremployee.views.pickupview.title',
        srfSubTitle: 'entities.hremployee.views.pickupview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof HREmployeePickupViewBase
     */
    protected containerModel: any = {
        view_pickupviewpanel: { name: 'pickupviewpanel', type: 'PICKUPVIEWPANEL' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'ec9d9fe37bbfc3fcb623e2dc34b48dbc';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof HREmployeePickupViewBase
     */
    public engine: PickupViewEngine = new PickupViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof HREmployeePickupViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            pickupviewpanel: this.$refs.pickupviewpanel,
            keyPSDEField: 'hremployee',
            majorPSDEField: 'employeename',
            isLoadDefault: true,
        });
    }

    /**
     * pickupviewpanel 部件 selectionchange 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HREmployeePickupViewBase
     */
    public pickupviewpanel_selectionchange($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'selectionchange', $event);
    }

    /**
     * pickupviewpanel 部件 activated 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HREmployeePickupViewBase
     */
    public pickupviewpanel_activated($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'activated', $event);
    }

    /**
     * pickupviewpanel 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof HREmployeePickupViewBase
     */
    public pickupviewpanel_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('pickupviewpanel', 'load', $event);
    }


}